# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_db_system_source_details import CreateDbSystemSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDbSystemSourceFromBackupDetails(CreateDbSystemSourceDetails):
    """
    Use the backupId to specify from which backup the new DB System will be created.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDbSystemSourceFromBackupDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.mysql.models.CreateDbSystemSourceFromBackupDetails.source_type` attribute
        of this class is ``BACKUP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this CreateDbSystemSourceFromBackupDetails.
            Allowed values for this property are: "NONE", "BACKUP", "IMPORTURL"
        :type source_type: str

        :param backup_id:
            The value to assign to the backup_id property of this CreateDbSystemSourceFromBackupDetails.
        :type backup_id: str

        """
        self.swagger_types = {
            'source_type': 'str',
            'backup_id': 'str'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'backup_id': 'backupId'
        }

        self._source_type = None
        self._backup_id = None
        self._source_type = 'BACKUP'

    @property
    def backup_id(self):
        """
        **[Required]** Gets the backup_id of this CreateDbSystemSourceFromBackupDetails.
        The OCID of the backup to be used as the source for the new DB System.


        :return: The backup_id of this CreateDbSystemSourceFromBackupDetails.
        :rtype: str
        """
        return self._backup_id

    @backup_id.setter
    def backup_id(self, backup_id):
        """
        Sets the backup_id of this CreateDbSystemSourceFromBackupDetails.
        The OCID of the backup to be used as the source for the new DB System.


        :param backup_id: The backup_id of this CreateDbSystemSourceFromBackupDetails.
        :type: str
        """
        self._backup_id = backup_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExternalNonContainerDatabaseSummary(object):
    """
    An Oracle Cloud Infrastructure external non-container database resource. This resource is used to manage a non-container
    database located outside of Oracle Cloud.
    """

    #: A constant which can be used with the lifecycle_state property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "NOT_CONNECTED"
    LIFECYCLE_STATE_NOT_CONNECTED = "NOT_CONNECTED"

    #: A constant which can be used with the lifecycle_state property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the database_edition property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "STANDARD_EDITION"
    DATABASE_EDITION_STANDARD_EDITION = "STANDARD_EDITION"

    #: A constant which can be used with the database_edition property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "ENTERPRISE_EDITION"
    DATABASE_EDITION_ENTERPRISE_EDITION = "ENTERPRISE_EDITION"

    #: A constant which can be used with the database_edition property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "ENTERPRISE_EDITION_HIGH_PERFORMANCE"
    DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = "ENTERPRISE_EDITION_HIGH_PERFORMANCE"

    #: A constant which can be used with the database_edition property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"
    DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"

    #: A constant which can be used with the database_configuration property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "RAC"
    DATABASE_CONFIGURATION_RAC = "RAC"

    #: A constant which can be used with the database_configuration property of a ExternalNonContainerDatabaseSummary.
    #: This constant has a value of "SINGLE_INSTANCE"
    DATABASE_CONFIGURATION_SINGLE_INSTANCE = "SINGLE_INSTANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new ExternalNonContainerDatabaseSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operations_insights_config:
            The value to assign to the operations_insights_config property of this ExternalNonContainerDatabaseSummary.
        :type operations_insights_config: oci.database.models.OperationsInsightsConfig

        :param compartment_id:
            The value to assign to the compartment_id property of this ExternalNonContainerDatabaseSummary.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ExternalNonContainerDatabaseSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ExternalNonContainerDatabaseSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this ExternalNonContainerDatabaseSummary.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ExternalNonContainerDatabaseSummary.
        :type id: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ExternalNonContainerDatabaseSummary.
        :type lifecycle_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ExternalNonContainerDatabaseSummary.
            Allowed values for this property are: "PROVISIONING", "NOT_CONNECTED", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this ExternalNonContainerDatabaseSummary.
        :type time_created: datetime

        :param db_unique_name:
            The value to assign to the db_unique_name property of this ExternalNonContainerDatabaseSummary.
        :type db_unique_name: str

        :param db_id:
            The value to assign to the db_id property of this ExternalNonContainerDatabaseSummary.
        :type db_id: str

        :param database_version:
            The value to assign to the database_version property of this ExternalNonContainerDatabaseSummary.
        :type database_version: str

        :param database_edition:
            The value to assign to the database_edition property of this ExternalNonContainerDatabaseSummary.
            Allowed values for this property are: "STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_edition: str

        :param time_zone:
            The value to assign to the time_zone property of this ExternalNonContainerDatabaseSummary.
        :type time_zone: str

        :param character_set:
            The value to assign to the character_set property of this ExternalNonContainerDatabaseSummary.
        :type character_set: str

        :param ncharacter_set:
            The value to assign to the ncharacter_set property of this ExternalNonContainerDatabaseSummary.
        :type ncharacter_set: str

        :param db_packs:
            The value to assign to the db_packs property of this ExternalNonContainerDatabaseSummary.
        :type db_packs: str

        :param database_configuration:
            The value to assign to the database_configuration property of this ExternalNonContainerDatabaseSummary.
            Allowed values for this property are: "RAC", "SINGLE_INSTANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_configuration: str

        :param database_management_config:
            The value to assign to the database_management_config property of this ExternalNonContainerDatabaseSummary.
        :type database_management_config: oci.database.models.DatabaseManagementConfig

        """
        self.swagger_types = {
            'operations_insights_config': 'OperationsInsightsConfig',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'id': 'str',
            'lifecycle_details': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'db_unique_name': 'str',
            'db_id': 'str',
            'database_version': 'str',
            'database_edition': 'str',
            'time_zone': 'str',
            'character_set': 'str',
            'ncharacter_set': 'str',
            'db_packs': 'str',
            'database_configuration': 'str',
            'database_management_config': 'DatabaseManagementConfig'
        }

        self.attribute_map = {
            'operations_insights_config': 'operationsInsightsConfig',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'id': 'id',
            'lifecycle_details': 'lifecycleDetails',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'db_unique_name': 'dbUniqueName',
            'db_id': 'dbId',
            'database_version': 'databaseVersion',
            'database_edition': 'databaseEdition',
            'time_zone': 'timeZone',
            'character_set': 'characterSet',
            'ncharacter_set': 'ncharacterSet',
            'db_packs': 'dbPacks',
            'database_configuration': 'databaseConfiguration',
            'database_management_config': 'databaseManagementConfig'
        }

        self._operations_insights_config = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._display_name = None
        self._id = None
        self._lifecycle_details = None
        self._lifecycle_state = None
        self._time_created = None
        self._db_unique_name = None
        self._db_id = None
        self._database_version = None
        self._database_edition = None
        self._time_zone = None
        self._character_set = None
        self._ncharacter_set = None
        self._db_packs = None
        self._database_configuration = None
        self._database_management_config = None

    @property
    def operations_insights_config(self):
        """
        Gets the operations_insights_config of this ExternalNonContainerDatabaseSummary.

        :return: The operations_insights_config of this ExternalNonContainerDatabaseSummary.
        :rtype: oci.database.models.OperationsInsightsConfig
        """
        return self._operations_insights_config

    @operations_insights_config.setter
    def operations_insights_config(self, operations_insights_config):
        """
        Sets the operations_insights_config of this ExternalNonContainerDatabaseSummary.

        :param operations_insights_config: The operations_insights_config of this ExternalNonContainerDatabaseSummary.
        :type: oci.database.models.OperationsInsightsConfig
        """
        self._operations_insights_config = operations_insights_config

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ExternalNonContainerDatabaseSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ExternalNonContainerDatabaseSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ExternalNonContainerDatabaseSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ExternalNonContainerDatabaseSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ExternalNonContainerDatabaseSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ExternalNonContainerDatabaseSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ExternalNonContainerDatabaseSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ExternalNonContainerDatabaseSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ExternalNonContainerDatabaseSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ExternalNonContainerDatabaseSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ExternalNonContainerDatabaseSummary.
        The user-friendly name for the external database. The name does not have to be unique.


        :return: The display_name of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ExternalNonContainerDatabaseSummary.
        The user-friendly name for the external database. The name does not have to be unique.


        :param display_name: The display_name of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ExternalNonContainerDatabaseSummary.
        The `OCID`__ of the Oracle Cloud Infrastructure external database resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExternalNonContainerDatabaseSummary.
        The `OCID`__ of the Oracle Cloud Infrastructure external database resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ExternalNonContainerDatabaseSummary.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ExternalNonContainerDatabaseSummary.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ExternalNonContainerDatabaseSummary.
        The current state of the Oracle Cloud Infrastructure external database resource.

        Allowed values for this property are: "PROVISIONING", "NOT_CONNECTED", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ExternalNonContainerDatabaseSummary.
        The current state of the Oracle Cloud Infrastructure external database resource.


        :param lifecycle_state: The lifecycle_state of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        allowed_values = ["PROVISIONING", "NOT_CONNECTED", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ExternalNonContainerDatabaseSummary.
        The date and time the database was created.


        :return: The time_created of this ExternalNonContainerDatabaseSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ExternalNonContainerDatabaseSummary.
        The date and time the database was created.


        :param time_created: The time_created of this ExternalNonContainerDatabaseSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def db_unique_name(self):
        """
        Gets the db_unique_name of this ExternalNonContainerDatabaseSummary.
        The `DB_UNIQUE_NAME` of the external database.


        :return: The db_unique_name of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this ExternalNonContainerDatabaseSummary.
        The `DB_UNIQUE_NAME` of the external database.


        :param db_unique_name: The db_unique_name of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def db_id(self):
        """
        Gets the db_id of this ExternalNonContainerDatabaseSummary.
        The Oracle Database ID, which identifies an Oracle Database located outside of Oracle Cloud.


        :return: The db_id of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._db_id

    @db_id.setter
    def db_id(self, db_id):
        """
        Sets the db_id of this ExternalNonContainerDatabaseSummary.
        The Oracle Database ID, which identifies an Oracle Database located outside of Oracle Cloud.


        :param db_id: The db_id of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._db_id = db_id

    @property
    def database_version(self):
        """
        Gets the database_version of this ExternalNonContainerDatabaseSummary.
        The Oracle Database version.


        :return: The database_version of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._database_version

    @database_version.setter
    def database_version(self, database_version):
        """
        Sets the database_version of this ExternalNonContainerDatabaseSummary.
        The Oracle Database version.


        :param database_version: The database_version of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._database_version = database_version

    @property
    def database_edition(self):
        """
        Gets the database_edition of this ExternalNonContainerDatabaseSummary.
        The Oracle Database edition.

        Allowed values for this property are: "STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_edition of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._database_edition

    @database_edition.setter
    def database_edition(self, database_edition):
        """
        Sets the database_edition of this ExternalNonContainerDatabaseSummary.
        The Oracle Database edition.


        :param database_edition: The database_edition of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        allowed_values = ["STANDARD_EDITION", "ENTERPRISE_EDITION", "ENTERPRISE_EDITION_HIGH_PERFORMANCE", "ENTERPRISE_EDITION_EXTREME_PERFORMANCE"]
        if not value_allowed_none_or_none_sentinel(database_edition, allowed_values):
            database_edition = 'UNKNOWN_ENUM_VALUE'
        self._database_edition = database_edition

    @property
    def time_zone(self):
        """
        Gets the time_zone of this ExternalNonContainerDatabaseSummary.
        The time zone of the external database.
        It is a time zone offset (a character type in the format '[+|-]TZH:TZM') or a time zone region name,
        depending on how the time zone value was specified when the database was created / last altered.


        :return: The time_zone of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this ExternalNonContainerDatabaseSummary.
        The time zone of the external database.
        It is a time zone offset (a character type in the format '[+|-]TZH:TZM') or a time zone region name,
        depending on how the time zone value was specified when the database was created / last altered.


        :param time_zone: The time_zone of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def character_set(self):
        """
        Gets the character_set of this ExternalNonContainerDatabaseSummary.
        The character set of the external database.


        :return: The character_set of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._character_set

    @character_set.setter
    def character_set(self, character_set):
        """
        Sets the character_set of this ExternalNonContainerDatabaseSummary.
        The character set of the external database.


        :param character_set: The character_set of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._character_set = character_set

    @property
    def ncharacter_set(self):
        """
        Gets the ncharacter_set of this ExternalNonContainerDatabaseSummary.
        The national character of the external database.


        :return: The ncharacter_set of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._ncharacter_set

    @ncharacter_set.setter
    def ncharacter_set(self, ncharacter_set):
        """
        Sets the ncharacter_set of this ExternalNonContainerDatabaseSummary.
        The national character of the external database.


        :param ncharacter_set: The ncharacter_set of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._ncharacter_set = ncharacter_set

    @property
    def db_packs(self):
        """
        Gets the db_packs of this ExternalNonContainerDatabaseSummary.
        The database packs licensed for the external Oracle Database.


        :return: The db_packs of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._db_packs

    @db_packs.setter
    def db_packs(self, db_packs):
        """
        Sets the db_packs of this ExternalNonContainerDatabaseSummary.
        The database packs licensed for the external Oracle Database.


        :param db_packs: The db_packs of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        self._db_packs = db_packs

    @property
    def database_configuration(self):
        """
        Gets the database_configuration of this ExternalNonContainerDatabaseSummary.
        The Oracle Database configuration

        Allowed values for this property are: "RAC", "SINGLE_INSTANCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_configuration of this ExternalNonContainerDatabaseSummary.
        :rtype: str
        """
        return self._database_configuration

    @database_configuration.setter
    def database_configuration(self, database_configuration):
        """
        Sets the database_configuration of this ExternalNonContainerDatabaseSummary.
        The Oracle Database configuration


        :param database_configuration: The database_configuration of this ExternalNonContainerDatabaseSummary.
        :type: str
        """
        allowed_values = ["RAC", "SINGLE_INSTANCE"]
        if not value_allowed_none_or_none_sentinel(database_configuration, allowed_values):
            database_configuration = 'UNKNOWN_ENUM_VALUE'
        self._database_configuration = database_configuration

    @property
    def database_management_config(self):
        """
        Gets the database_management_config of this ExternalNonContainerDatabaseSummary.

        :return: The database_management_config of this ExternalNonContainerDatabaseSummary.
        :rtype: oci.database.models.DatabaseManagementConfig
        """
        return self._database_management_config

    @database_management_config.setter
    def database_management_config(self, database_management_config):
        """
        Sets the database_management_config of this ExternalNonContainerDatabaseSummary.

        :param database_management_config: The database_management_config of this ExternalNonContainerDatabaseSummary.
        :type: oci.database.models.DatabaseManagementConfig
        """
        self._database_management_config = database_management_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Tag(object):
    """
    Definition of a tag which is a key value pair.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Tag object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tag_name:
            The value to assign to the tag_name property of this Tag.
        :type tag_name: str

        :param tag_value:
            The value to assign to the tag_value property of this Tag.
        :type tag_value: str

        """
        self.swagger_types = {
            'tag_name': 'str',
            'tag_value': 'str'
        }

        self.attribute_map = {
            'tag_name': 'tagName',
            'tag_value': 'tagValue'
        }

        self._tag_name = None
        self._tag_value = None

    @property
    def tag_name(self):
        """
        **[Required]** Gets the tag_name of this Tag.
        Key that specifies the tag name.


        :return: The tag_name of this Tag.
        :rtype: str
        """
        return self._tag_name

    @tag_name.setter
    def tag_name(self, tag_name):
        """
        Sets the tag_name of this Tag.
        Key that specifies the tag name.


        :param tag_name: The tag_name of this Tag.
        :type: str
        """
        self._tag_name = tag_name

    @property
    def tag_value(self):
        """
        **[Required]** Gets the tag_value of this Tag.
        Value associated with the tag key.


        :return: The tag_value of this Tag.
        :rtype: str
        """
        return self._tag_value

    @tag_value.setter
    def tag_value(self, tag_value):
        """
        Sets the tag_value of this Tag.
        Value associated with the tag key.


        :param tag_value: The tag_value of this Tag.
        :type: str
        """
        self._tag_value = tag_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateManagedInstanceDetails(object):
    """
    Information to update a managed instance
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateManagedInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param notification_topic_id:
            The value to assign to the notification_topic_id property of this UpdateManagedInstanceDetails.
        :type notification_topic_id: str

        :param is_data_collection_authorized:
            The value to assign to the is_data_collection_authorized property of this UpdateManagedInstanceDetails.
        :type is_data_collection_authorized: bool

        """
        self.swagger_types = {
            'notification_topic_id': 'str',
            'is_data_collection_authorized': 'bool'
        }

        self.attribute_map = {
            'notification_topic_id': 'notificationTopicId',
            'is_data_collection_authorized': 'isDataCollectionAuthorized'
        }

        self._notification_topic_id = None
        self._is_data_collection_authorized = None

    @property
    def notification_topic_id(self):
        """
        Gets the notification_topic_id of this UpdateManagedInstanceDetails.
        OCID of the ONS topic used to send notification to users


        :return: The notification_topic_id of this UpdateManagedInstanceDetails.
        :rtype: str
        """
        return self._notification_topic_id

    @notification_topic_id.setter
    def notification_topic_id(self, notification_topic_id):
        """
        Sets the notification_topic_id of this UpdateManagedInstanceDetails.
        OCID of the ONS topic used to send notification to users


        :param notification_topic_id: The notification_topic_id of this UpdateManagedInstanceDetails.
        :type: str
        """
        self._notification_topic_id = notification_topic_id

    @property
    def is_data_collection_authorized(self):
        """
        Gets the is_data_collection_authorized of this UpdateManagedInstanceDetails.
        True if user allow data collection for this instance


        :return: The is_data_collection_authorized of this UpdateManagedInstanceDetails.
        :rtype: bool
        """
        return self._is_data_collection_authorized

    @is_data_collection_authorized.setter
    def is_data_collection_authorized(self, is_data_collection_authorized):
        """
        Sets the is_data_collection_authorized of this UpdateManagedInstanceDetails.
        True if user allow data collection for this instance


        :param is_data_collection_authorized: The is_data_collection_authorized of this UpdateManagedInstanceDetails.
        :type: bool
        """
        self._is_data_collection_authorized = is_data_collection_authorized

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_details import DatabaseDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstalledDatabaseDetails(DatabaseDetails):
    """
    The details of the database running on-premises or on a compute instance.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstalledDatabaseDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.InstalledDatabaseDetails.database_type` attribute
        of this class is ``INSTALLED_DATABASE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_type:
            The value to assign to the database_type property of this InstalledDatabaseDetails.
            Allowed values for this property are: "DATABASE_CLOUD_SERVICE", "AUTONOMOUS_DATABASE", "INSTALLED_DATABASE"
        :type database_type: str

        :param infrastructure_type:
            The value to assign to the infrastructure_type property of this InstalledDatabaseDetails.
            Allowed values for this property are: "ORACLE_CLOUD", "CLOUD_AT_CUSTOMER", "ON_PREMISES", "NON_ORACLE_CLOUD"
        :type infrastructure_type: str

        :param instance_id:
            The value to assign to the instance_id property of this InstalledDatabaseDetails.
        :type instance_id: str

        :param ip_addresses:
            The value to assign to the ip_addresses property of this InstalledDatabaseDetails.
        :type ip_addresses: list[str]

        :param listener_port:
            The value to assign to the listener_port property of this InstalledDatabaseDetails.
        :type listener_port: int

        :param service_name:
            The value to assign to the service_name property of this InstalledDatabaseDetails.
        :type service_name: str

        """
        self.swagger_types = {
            'database_type': 'str',
            'infrastructure_type': 'str',
            'instance_id': 'str',
            'ip_addresses': 'list[str]',
            'listener_port': 'int',
            'service_name': 'str'
        }

        self.attribute_map = {
            'database_type': 'databaseType',
            'infrastructure_type': 'infrastructureType',
            'instance_id': 'instanceId',
            'ip_addresses': 'ipAddresses',
            'listener_port': 'listenerPort',
            'service_name': 'serviceName'
        }

        self._database_type = None
        self._infrastructure_type = None
        self._instance_id = None
        self._ip_addresses = None
        self._listener_port = None
        self._service_name = None
        self._database_type = 'INSTALLED_DATABASE'

    @property
    def instance_id(self):
        """
        Gets the instance_id of this InstalledDatabaseDetails.
        The OCID of the compute instance on which the database is running.


        :return: The instance_id of this InstalledDatabaseDetails.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this InstalledDatabaseDetails.
        The OCID of the compute instance on which the database is running.


        :param instance_id: The instance_id of this InstalledDatabaseDetails.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def ip_addresses(self):
        """
        Gets the ip_addresses of this InstalledDatabaseDetails.
        The list of database host IP Addresses. Fully qualified domain names can be used if connectionType is 'ONPREM_CONNECTOR'.


        :return: The ip_addresses of this InstalledDatabaseDetails.
        :rtype: list[str]
        """
        return self._ip_addresses

    @ip_addresses.setter
    def ip_addresses(self, ip_addresses):
        """
        Sets the ip_addresses of this InstalledDatabaseDetails.
        The list of database host IP Addresses. Fully qualified domain names can be used if connectionType is 'ONPREM_CONNECTOR'.


        :param ip_addresses: The ip_addresses of this InstalledDatabaseDetails.
        :type: list[str]
        """
        self._ip_addresses = ip_addresses

    @property
    def listener_port(self):
        """
        Gets the listener_port of this InstalledDatabaseDetails.
        The port number of the database listener.


        :return: The listener_port of this InstalledDatabaseDetails.
        :rtype: int
        """
        return self._listener_port

    @listener_port.setter
    def listener_port(self, listener_port):
        """
        Sets the listener_port of this InstalledDatabaseDetails.
        The port number of the database listener.


        :param listener_port: The listener_port of this InstalledDatabaseDetails.
        :type: int
        """
        self._listener_port = listener_port

    @property
    def service_name(self):
        """
        Gets the service_name of this InstalledDatabaseDetails.
        The service name of the database registered as target database.


        :return: The service_name of this InstalledDatabaseDetails.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this InstalledDatabaseDetails.
        The service name of the database registered as target database.


        :param service_name: The service_name of this InstalledDatabaseDetails.
        :type: str
        """
        self._service_name = service_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PerSignalDetails(object):
    """
    Detailed information like statistics, metrics and status for a signal
    """

    #: A constant which can be used with the status property of a PerSignalDetails.
    #: This constant has a value of "ACCEPTED"
    STATUS_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the status property of a PerSignalDetails.
    #: This constant has a value of "DROPPED"
    STATUS_DROPPED = "DROPPED"

    #: A constant which can be used with the status property of a PerSignalDetails.
    #: This constant has a value of "OTHER"
    STATUS_OTHER = "OTHER"

    def __init__(self, **kwargs):
        """
        Initializes a new PerSignalDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param signal_name:
            The value to assign to the signal_name property of this PerSignalDetails.
        :type signal_name: str

        :param mvi_ratio:
            The value to assign to the mvi_ratio property of this PerSignalDetails.
        :type mvi_ratio: float

        :param is_quantized:
            The value to assign to the is_quantized property of this PerSignalDetails.
        :type is_quantized: bool

        :param fap:
            The value to assign to the fap property of this PerSignalDetails.
        :type fap: float

        :param min:
            The value to assign to the min property of this PerSignalDetails.
        :type min: float

        :param max:
            The value to assign to the max property of this PerSignalDetails.
        :type max: float

        :param std:
            The value to assign to the std property of this PerSignalDetails.
        :type std: float

        :param status:
            The value to assign to the status property of this PerSignalDetails.
            Allowed values for this property are: "ACCEPTED", "DROPPED", "OTHER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param details:
            The value to assign to the details property of this PerSignalDetails.
        :type details: str

        """
        self.swagger_types = {
            'signal_name': 'str',
            'mvi_ratio': 'float',
            'is_quantized': 'bool',
            'fap': 'float',
            'min': 'float',
            'max': 'float',
            'std': 'float',
            'status': 'str',
            'details': 'str'
        }

        self.attribute_map = {
            'signal_name': 'signalName',
            'mvi_ratio': 'mviRatio',
            'is_quantized': 'isQuantized',
            'fap': 'fap',
            'min': 'min',
            'max': 'max',
            'std': 'std',
            'status': 'status',
            'details': 'details'
        }

        self._signal_name = None
        self._mvi_ratio = None
        self._is_quantized = None
        self._fap = None
        self._min = None
        self._max = None
        self._std = None
        self._status = None
        self._details = None

    @property
    def signal_name(self):
        """
        **[Required]** Gets the signal_name of this PerSignalDetails.
        The name of a signal.


        :return: The signal_name of this PerSignalDetails.
        :rtype: str
        """
        return self._signal_name

    @signal_name.setter
    def signal_name(self, signal_name):
        """
        Sets the signal_name of this PerSignalDetails.
        The name of a signal.


        :param signal_name: The signal_name of this PerSignalDetails.
        :type: str
        """
        self._signal_name = signal_name

    @property
    def mvi_ratio(self):
        """
        Gets the mvi_ratio of this PerSignalDetails.
        The ratio of missing values in a signal filled/imputed by the IDP algorithm.


        :return: The mvi_ratio of this PerSignalDetails.
        :rtype: float
        """
        return self._mvi_ratio

    @mvi_ratio.setter
    def mvi_ratio(self, mvi_ratio):
        """
        Sets the mvi_ratio of this PerSignalDetails.
        The ratio of missing values in a signal filled/imputed by the IDP algorithm.


        :param mvi_ratio: The mvi_ratio of this PerSignalDetails.
        :type: float
        """
        self._mvi_ratio = mvi_ratio

    @property
    def is_quantized(self):
        """
        Gets the is_quantized of this PerSignalDetails.
        A boolean value to indicate if a signal is quantized or not.


        :return: The is_quantized of this PerSignalDetails.
        :rtype: bool
        """
        return self._is_quantized

    @is_quantized.setter
    def is_quantized(self, is_quantized):
        """
        Sets the is_quantized of this PerSignalDetails.
        A boolean value to indicate if a signal is quantized or not.


        :param is_quantized: The is_quantized of this PerSignalDetails.
        :type: bool
        """
        self._is_quantized = is_quantized

    @property
    def fap(self):
        """
        Gets the fap of this PerSignalDetails.
        Accuracy metric for a signal.


        :return: The fap of this PerSignalDetails.
        :rtype: float
        """
        return self._fap

    @fap.setter
    def fap(self, fap):
        """
        Sets the fap of this PerSignalDetails.
        Accuracy metric for a signal.


        :param fap: The fap of this PerSignalDetails.
        :type: float
        """
        self._fap = fap

    @property
    def min(self):
        """
        **[Required]** Gets the min of this PerSignalDetails.
        Min value within a signal.


        :return: The min of this PerSignalDetails.
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """
        Sets the min of this PerSignalDetails.
        Min value within a signal.


        :param min: The min of this PerSignalDetails.
        :type: float
        """
        self._min = min

    @property
    def max(self):
        """
        **[Required]** Gets the max of this PerSignalDetails.
        Max value within a signal.


        :return: The max of this PerSignalDetails.
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this PerSignalDetails.
        Max value within a signal.


        :param max: The max of this PerSignalDetails.
        :type: float
        """
        self._max = max

    @property
    def std(self):
        """
        **[Required]** Gets the std of this PerSignalDetails.
        Standard deviation of values within a signal.


        :return: The std of this PerSignalDetails.
        :rtype: float
        """
        return self._std

    @std.setter
    def std(self, std):
        """
        Sets the std of this PerSignalDetails.
        Standard deviation of values within a signal.


        :param std: The std of this PerSignalDetails.
        :type: float
        """
        self._std = std

    @property
    def status(self):
        """
        **[Required]** Gets the status of this PerSignalDetails.
        Status of the signal:
         * ACCEPTED - the signal is used for training the model
         * DROPPED - the signal does not meet requirement, and is dropped before training the model.
         * OTHER - placeholder for other status

        Allowed values for this property are: "ACCEPTED", "DROPPED", "OTHER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this PerSignalDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this PerSignalDetails.
        Status of the signal:
         * ACCEPTED - the signal is used for training the model
         * DROPPED - the signal does not meet requirement, and is dropped before training the model.
         * OTHER - placeholder for other status


        :param status: The status of this PerSignalDetails.
        :type: str
        """
        allowed_values = ["ACCEPTED", "DROPPED", "OTHER"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def details(self):
        """
        Gets the details of this PerSignalDetails.
        detailed information for a signal.


        :return: The details of this PerSignalDetails.
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this PerSignalDetails.
        detailed information for a signal.


        :param details: The details of this PerSignalDetails.
        :type: str
        """
        self._details = details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateModelConfigurationDetails(object):
    """
    The model configuration details for update.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateModelConfigurationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_id:
            The value to assign to the model_id property of this UpdateModelConfigurationDetails.
        :type model_id: str

        :param instance_configuration:
            The value to assign to the instance_configuration property of this UpdateModelConfigurationDetails.
        :type instance_configuration: oci.data_science.models.InstanceConfiguration

        :param scaling_policy:
            The value to assign to the scaling_policy property of this UpdateModelConfigurationDetails.
        :type scaling_policy: oci.data_science.models.ScalingPolicy

        :param bandwidth_mbps:
            The value to assign to the bandwidth_mbps property of this UpdateModelConfigurationDetails.
        :type bandwidth_mbps: int

        """
        self.swagger_types = {
            'model_id': 'str',
            'instance_configuration': 'InstanceConfiguration',
            'scaling_policy': 'ScalingPolicy',
            'bandwidth_mbps': 'int'
        }

        self.attribute_map = {
            'model_id': 'modelId',
            'instance_configuration': 'instanceConfiguration',
            'scaling_policy': 'scalingPolicy',
            'bandwidth_mbps': 'bandwidthMbps'
        }

        self._model_id = None
        self._instance_configuration = None
        self._scaling_policy = None
        self._bandwidth_mbps = None

    @property
    def model_id(self):
        """
        **[Required]** Gets the model_id of this UpdateModelConfigurationDetails.
        The OCID of the model you want to update.


        :return: The model_id of this UpdateModelConfigurationDetails.
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """
        Sets the model_id of this UpdateModelConfigurationDetails.
        The OCID of the model you want to update.


        :param model_id: The model_id of this UpdateModelConfigurationDetails.
        :type: str
        """
        self._model_id = model_id

    @property
    def instance_configuration(self):
        """
        Gets the instance_configuration of this UpdateModelConfigurationDetails.

        :return: The instance_configuration of this UpdateModelConfigurationDetails.
        :rtype: oci.data_science.models.InstanceConfiguration
        """
        return self._instance_configuration

    @instance_configuration.setter
    def instance_configuration(self, instance_configuration):
        """
        Sets the instance_configuration of this UpdateModelConfigurationDetails.

        :param instance_configuration: The instance_configuration of this UpdateModelConfigurationDetails.
        :type: oci.data_science.models.InstanceConfiguration
        """
        self._instance_configuration = instance_configuration

    @property
    def scaling_policy(self):
        """
        Gets the scaling_policy of this UpdateModelConfigurationDetails.

        :return: The scaling_policy of this UpdateModelConfigurationDetails.
        :rtype: oci.data_science.models.ScalingPolicy
        """
        return self._scaling_policy

    @scaling_policy.setter
    def scaling_policy(self, scaling_policy):
        """
        Sets the scaling_policy of this UpdateModelConfigurationDetails.

        :param scaling_policy: The scaling_policy of this UpdateModelConfigurationDetails.
        :type: oci.data_science.models.ScalingPolicy
        """
        self._scaling_policy = scaling_policy

    @property
    def bandwidth_mbps(self):
        """
        Gets the bandwidth_mbps of this UpdateModelConfigurationDetails.
        The network bandwidth for the model.


        :return: The bandwidth_mbps of this UpdateModelConfigurationDetails.
        :rtype: int
        """
        return self._bandwidth_mbps

    @bandwidth_mbps.setter
    def bandwidth_mbps(self, bandwidth_mbps):
        """
        Sets the bandwidth_mbps of this UpdateModelConfigurationDetails.
        The network bandwidth for the model.


        :param bandwidth_mbps: The bandwidth_mbps of this UpdateModelConfigurationDetails.
        :type: int
        """
        self._bandwidth_mbps = bandwidth_mbps

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OcpuUtilizationInfo(object):
    """
    Ocpu utilization for a VM host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OcpuUtilizationInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param host:
            The value to assign to the host property of this OcpuUtilizationInfo.
        :type host: str

        :param ocpu_utilization_number:
            The value to assign to the ocpu_utilization_number property of this OcpuUtilizationInfo.
        :type ocpu_utilization_number: float

        :param ocpu_capacity_number:
            The value to assign to the ocpu_capacity_number property of this OcpuUtilizationInfo.
        :type ocpu_capacity_number: float

        """
        self.swagger_types = {
            'host': 'str',
            'ocpu_utilization_number': 'float',
            'ocpu_capacity_number': 'float'
        }

        self.attribute_map = {
            'host': 'host',
            'ocpu_utilization_number': 'ocpuUtilizationNumber',
            'ocpu_capacity_number': 'ocpuCapacityNumber'
        }

        self._host = None
        self._ocpu_utilization_number = None
        self._ocpu_capacity_number = None

    @property
    def host(self):
        """
        Gets the host of this OcpuUtilizationInfo.
        Host name of VM


        :return: The host of this OcpuUtilizationInfo.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this OcpuUtilizationInfo.
        Host name of VM


        :param host: The host of this OcpuUtilizationInfo.
        :type: str
        """
        self._host = host

    @property
    def ocpu_utilization_number(self):
        """
        Gets the ocpu_utilization_number of this OcpuUtilizationInfo.
        Number of OCPU utilized


        :return: The ocpu_utilization_number of this OcpuUtilizationInfo.
        :rtype: float
        """
        return self._ocpu_utilization_number

    @ocpu_utilization_number.setter
    def ocpu_utilization_number(self, ocpu_utilization_number):
        """
        Sets the ocpu_utilization_number of this OcpuUtilizationInfo.
        Number of OCPU utilized


        :param ocpu_utilization_number: The ocpu_utilization_number of this OcpuUtilizationInfo.
        :type: float
        """
        self._ocpu_utilization_number = ocpu_utilization_number

    @property
    def ocpu_capacity_number(self):
        """
        Gets the ocpu_capacity_number of this OcpuUtilizationInfo.
        Number of total OCPU capacity on the host


        :return: The ocpu_capacity_number of this OcpuUtilizationInfo.
        :rtype: float
        """
        return self._ocpu_capacity_number

    @ocpu_capacity_number.setter
    def ocpu_capacity_number(self, ocpu_capacity_number):
        """
        Sets the ocpu_capacity_number of this OcpuUtilizationInfo.
        Number of total OCPU capacity on the host


        :param ocpu_capacity_number: The ocpu_capacity_number of this OcpuUtilizationInfo.
        :type: float
        """
        self._ocpu_capacity_number = ocpu_capacity_number

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .autonomous_database_configuration_summary import AutonomousDatabaseConfigurationSummary
from .autonomous_database_insight import AutonomousDatabaseInsight
from .autonomous_database_insight_summary import AutonomousDatabaseInsightSummary
from .change_database_insight_compartment_details import ChangeDatabaseInsightCompartmentDetails
from .change_enterprise_manager_bridge_compartment_details import ChangeEnterpriseManagerBridgeCompartmentDetails
from .change_host_insight_compartment_details import ChangeHostInsightCompartmentDetails
from .connection_details import ConnectionDetails
from .create_database_insight_details import CreateDatabaseInsightDetails
from .create_em_managed_external_database_insight_details import CreateEmManagedExternalDatabaseInsightDetails
from .create_enterprise_manager_bridge_details import CreateEnterpriseManagerBridgeDetails
from .create_host_insight_details import CreateHostInsightDetails
from .create_macs_managed_external_host_insight_details import CreateMacsManagedExternalHostInsightDetails
from .credential_details import CredentialDetails
from .credentials_by_source import CredentialsBySource
from .db_external_instance import DBExternalInstance
from .db_external_properties import DBExternalProperties
from .dbos_config_instance import DBOSConfigInstance
from .database_configuration_collection import DatabaseConfigurationCollection
from .database_configuration_metric_group import DatabaseConfigurationMetricGroup
from .database_configuration_summary import DatabaseConfigurationSummary
from .database_details import DatabaseDetails
from .database_insight import DatabaseInsight
from .database_insight_summary import DatabaseInsightSummary
from .database_insights import DatabaseInsights
from .database_insights_collection import DatabaseInsightsCollection
from .em_managed_external_database_configuration_summary import EmManagedExternalDatabaseConfigurationSummary
from .em_managed_external_database_insight import EmManagedExternalDatabaseInsight
from .em_managed_external_database_insight_summary import EmManagedExternalDatabaseInsightSummary
from .enable_database_insight_details import EnableDatabaseInsightDetails
from .enable_em_managed_external_database_insight_details import EnableEmManagedExternalDatabaseInsightDetails
from .enable_host_insight_details import EnableHostInsightDetails
from .enable_macs_managed_external_host_insight_details import EnableMacsManagedExternalHostInsightDetails
from .enterprise_manager_bridge import EnterpriseManagerBridge
from .enterprise_manager_bridge_collection import EnterpriseManagerBridgeCollection
from .enterprise_manager_bridge_summary import EnterpriseManagerBridgeSummary
from .enterprise_manager_bridges import EnterpriseManagerBridges
from .historical_data_item import HistoricalDataItem
from .host_configuration_metric_group import HostConfigurationMetricGroup
from .host_cpu_hardware_configuration import HostCpuHardwareConfiguration
from .host_cpu_statistics import HostCpuStatistics
from .host_cpu_usage import HostCpuUsage
from .host_details import HostDetails
from .host_entities import HostEntities
from .host_hardware_configuration import HostHardwareConfiguration
from .host_importable_agent_entity_summary import HostImportableAgentEntitySummary
from .host_insight import HostInsight
from .host_insight_resource_statistics_aggregation import HostInsightResourceStatisticsAggregation
from .host_insight_summary import HostInsightSummary
from .host_insight_summary_collection import HostInsightSummaryCollection
from .host_insights import HostInsights
from .host_instance_map import HostInstanceMap
from .host_memory_configuration import HostMemoryConfiguration
from .host_memory_statistics import HostMemoryStatistics
from .host_memory_usage import HostMemoryUsage
from .host_network_activity_summary import HostNetworkActivitySummary
from .host_network_configuration import HostNetworkConfiguration
from .host_performance_metric_group import HostPerformanceMetricGroup
from .host_product import HostProduct
from .host_resource_allocation import HostResourceAllocation
from .host_resource_capacity_trend_aggregation import HostResourceCapacityTrendAggregation
from .host_resource_statistics import HostResourceStatistics
from .hosted_entity_collection import HostedEntityCollection
from .hosted_entity_summary import HostedEntitySummary
from .importable_agent_entity_summary import ImportableAgentEntitySummary
from .importable_agent_entity_summary_collection import ImportableAgentEntitySummaryCollection
from .importable_enterprise_manager_entity import ImportableEnterpriseManagerEntity
from .importable_enterprise_manager_entity_collection import ImportableEnterpriseManagerEntityCollection
from .ingest_database_configuration_details import IngestDatabaseConfigurationDetails
from .ingest_database_configuration_response_details import IngestDatabaseConfigurationResponseDetails
from .ingest_host_configuration_details import IngestHostConfigurationDetails
from .ingest_host_configuration_response_details import IngestHostConfigurationResponseDetails
from .ingest_host_metrics_details import IngestHostMetricsDetails
from .ingest_host_metrics_response_details import IngestHostMetricsResponseDetails
from .ingest_sql_bucket_details import IngestSqlBucketDetails
from .ingest_sql_bucket_response_details import IngestSqlBucketResponseDetails
from .ingest_sql_plan_lines_details import IngestSqlPlanLinesDetails
from .ingest_sql_plan_lines_response_details import IngestSqlPlanLinesResponseDetails
from .ingest_sql_text_details import IngestSqlTextDetails
from .ingest_sql_text_response_details import IngestSqlTextResponseDetails
from .macs_managed_external_database_configuration_summary import MacsManagedExternalDatabaseConfigurationSummary
from .macs_managed_external_database_insight import MacsManagedExternalDatabaseInsight
from .macs_managed_external_database_insight_summary import MacsManagedExternalDatabaseInsightSummary
from .macs_managed_external_host_insight import MacsManagedExternalHostInsight
from .macs_managed_external_host_insight_summary import MacsManagedExternalHostInsightSummary
from .projected_data_item import ProjectedDataItem
from .resource_capacity_trend_aggregation import ResourceCapacityTrendAggregation
from .resource_insight_current_utilization import ResourceInsightCurrentUtilization
from .resource_insight_projected_utilization import ResourceInsightProjectedUtilization
from .resource_insight_projected_utilization_item import ResourceInsightProjectedUtilizationItem
from .resource_statistics import ResourceStatistics
from .resource_statistics_aggregation import ResourceStatisticsAggregation
from .resource_usage_trend_aggregation import ResourceUsageTrendAggregation
from .sql_bucket import SqlBucket
from .sql_insight_aggregation import SqlInsightAggregation
from .sql_insight_aggregation_collection import SqlInsightAggregationCollection
from .sql_insight_thresholds import SqlInsightThresholds
from .sql_inventory import SqlInventory
from .sql_plan_collection import SqlPlanCollection
from .sql_plan_insight_aggregation import SqlPlanInsightAggregation
from .sql_plan_insight_aggregation_collection import SqlPlanInsightAggregationCollection
from .sql_plan_insights import SqlPlanInsights
from .sql_plan_line import SqlPlanLine
from .sql_plan_summary import SqlPlanSummary
from .sql_response_time_distribution_aggregation import SqlResponseTimeDistributionAggregation
from .sql_response_time_distribution_aggregation_collection import SqlResponseTimeDistributionAggregationCollection
from .sql_search_collection import SqlSearchCollection
from .sql_search_summary import SqlSearchSummary
from .sql_statistic_aggregation import SqlStatisticAggregation
from .sql_statistic_aggregation_collection import SqlStatisticAggregationCollection
from .sql_statistics import SqlStatistics
from .sql_statistics_time_series import SqlStatisticsTimeSeries
from .sql_statistics_time_series_aggregation import SqlStatisticsTimeSeriesAggregation
from .sql_statistics_time_series_aggregation_collection import SqlStatisticsTimeSeriesAggregationCollection
from .sql_statistics_time_series_by_plan_aggregation import SqlStatisticsTimeSeriesByPlanAggregation
from .sql_statistics_time_series_by_plan_aggregation_collection import SqlStatisticsTimeSeriesByPlanAggregationCollection
from .sql_text import SqlText
from .sql_text_collection import SqlTextCollection
from .sql_text_summary import SqlTextSummary
from .summarize_database_insight_resource_capacity_trend_aggregation_collection import SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection
from .summarize_database_insight_resource_forecast_trend_aggregation import SummarizeDatabaseInsightResourceForecastTrendAggregation
from .summarize_database_insight_resource_statistics_aggregation_collection import SummarizeDatabaseInsightResourceStatisticsAggregationCollection
from .summarize_database_insight_resource_usage_aggregation import SummarizeDatabaseInsightResourceUsageAggregation
from .summarize_database_insight_resource_usage_trend_aggregation_collection import SummarizeDatabaseInsightResourceUsageTrendAggregationCollection
from .summarize_database_insight_resource_utilization_insight_aggregation import SummarizeDatabaseInsightResourceUtilizationInsightAggregation
from .summarize_database_insight_tablespace_usage_trend_aggregation_collection import SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection
from .summarize_host_insight_resource_capacity_trend_aggregation_collection import SummarizeHostInsightResourceCapacityTrendAggregationCollection
from .summarize_host_insight_resource_forecast_trend_aggregation import SummarizeHostInsightResourceForecastTrendAggregation
from .summarize_host_insight_resource_statistics_aggregation_collection import SummarizeHostInsightResourceStatisticsAggregationCollection
from .summarize_host_insight_resource_usage_aggregation import SummarizeHostInsightResourceUsageAggregation
from .summarize_host_insight_resource_usage_trend_aggregation_collection import SummarizeHostInsightResourceUsageTrendAggregationCollection
from .summarize_host_insight_resource_utilization_insight_aggregation import SummarizeHostInsightResourceUtilizationInsightAggregation
from .summary_statistics import SummaryStatistics
from .tablespace_usage_trend import TablespaceUsageTrend
from .tablespace_usage_trend_aggregation import TablespaceUsageTrendAggregation
from .update_autonomous_database_insight_details import UpdateAutonomousDatabaseInsightDetails
from .update_database_insight_details import UpdateDatabaseInsightDetails
from .update_em_managed_external_database_insight_details import UpdateEmManagedExternalDatabaseInsightDetails
from .update_enterprise_manager_bridge_details import UpdateEnterpriseManagerBridgeDetails
from .update_host_insight_details import UpdateHostInsightDetails
from .update_macs_managed_external_database_insight_details import UpdateMacsManagedExternalDatabaseInsightDetails
from .update_macs_managed_external_host_insight_details import UpdateMacsManagedExternalHostInsightDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_requests import WorkRequests

# Maps type names to classes for opsi services.
opsi_type_mapping = {
    "AutonomousDatabaseConfigurationSummary": AutonomousDatabaseConfigurationSummary,
    "AutonomousDatabaseInsight": AutonomousDatabaseInsight,
    "AutonomousDatabaseInsightSummary": AutonomousDatabaseInsightSummary,
    "ChangeDatabaseInsightCompartmentDetails": ChangeDatabaseInsightCompartmentDetails,
    "ChangeEnterpriseManagerBridgeCompartmentDetails": ChangeEnterpriseManagerBridgeCompartmentDetails,
    "ChangeHostInsightCompartmentDetails": ChangeHostInsightCompartmentDetails,
    "ConnectionDetails": ConnectionDetails,
    "CreateDatabaseInsightDetails": CreateDatabaseInsightDetails,
    "CreateEmManagedExternalDatabaseInsightDetails": CreateEmManagedExternalDatabaseInsightDetails,
    "CreateEnterpriseManagerBridgeDetails": CreateEnterpriseManagerBridgeDetails,
    "CreateHostInsightDetails": CreateHostInsightDetails,
    "CreateMacsManagedExternalHostInsightDetails": CreateMacsManagedExternalHostInsightDetails,
    "CredentialDetails": CredentialDetails,
    "CredentialsBySource": CredentialsBySource,
    "DBExternalInstance": DBExternalInstance,
    "DBExternalProperties": DBExternalProperties,
    "DBOSConfigInstance": DBOSConfigInstance,
    "DatabaseConfigurationCollection": DatabaseConfigurationCollection,
    "DatabaseConfigurationMetricGroup": DatabaseConfigurationMetricGroup,
    "DatabaseConfigurationSummary": DatabaseConfigurationSummary,
    "DatabaseDetails": DatabaseDetails,
    "DatabaseInsight": DatabaseInsight,
    "DatabaseInsightSummary": DatabaseInsightSummary,
    "DatabaseInsights": DatabaseInsights,
    "DatabaseInsightsCollection": DatabaseInsightsCollection,
    "EmManagedExternalDatabaseConfigurationSummary": EmManagedExternalDatabaseConfigurationSummary,
    "EmManagedExternalDatabaseInsight": EmManagedExternalDatabaseInsight,
    "EmManagedExternalDatabaseInsightSummary": EmManagedExternalDatabaseInsightSummary,
    "EnableDatabaseInsightDetails": EnableDatabaseInsightDetails,
    "EnableEmManagedExternalDatabaseInsightDetails": EnableEmManagedExternalDatabaseInsightDetails,
    "EnableHostInsightDetails": EnableHostInsightDetails,
    "EnableMacsManagedExternalHostInsightDetails": EnableMacsManagedExternalHostInsightDetails,
    "EnterpriseManagerBridge": EnterpriseManagerBridge,
    "EnterpriseManagerBridgeCollection": EnterpriseManagerBridgeCollection,
    "EnterpriseManagerBridgeSummary": EnterpriseManagerBridgeSummary,
    "EnterpriseManagerBridges": EnterpriseManagerBridges,
    "HistoricalDataItem": HistoricalDataItem,
    "HostConfigurationMetricGroup": HostConfigurationMetricGroup,
    "HostCpuHardwareConfiguration": HostCpuHardwareConfiguration,
    "HostCpuStatistics": HostCpuStatistics,
    "HostCpuUsage": HostCpuUsage,
    "HostDetails": HostDetails,
    "HostEntities": HostEntities,
    "HostHardwareConfiguration": HostHardwareConfiguration,
    "HostImportableAgentEntitySummary": HostImportableAgentEntitySummary,
    "HostInsight": HostInsight,
    "HostInsightResourceStatisticsAggregation": HostInsightResourceStatisticsAggregation,
    "HostInsightSummary": HostInsightSummary,
    "HostInsightSummaryCollection": HostInsightSummaryCollection,
    "HostInsights": HostInsights,
    "HostInstanceMap": HostInstanceMap,
    "HostMemoryConfiguration": HostMemoryConfiguration,
    "HostMemoryStatistics": HostMemoryStatistics,
    "HostMemoryUsage": HostMemoryUsage,
    "HostNetworkActivitySummary": HostNetworkActivitySummary,
    "HostNetworkConfiguration": HostNetworkConfiguration,
    "HostPerformanceMetricGroup": HostPerformanceMetricGroup,
    "HostProduct": HostProduct,
    "HostResourceAllocation": HostResourceAllocation,
    "HostResourceCapacityTrendAggregation": HostResourceCapacityTrendAggregation,
    "HostResourceStatistics": HostResourceStatistics,
    "HostedEntityCollection": HostedEntityCollection,
    "HostedEntitySummary": HostedEntitySummary,
    "ImportableAgentEntitySummary": ImportableAgentEntitySummary,
    "ImportableAgentEntitySummaryCollection": ImportableAgentEntitySummaryCollection,
    "ImportableEnterpriseManagerEntity": ImportableEnterpriseManagerEntity,
    "ImportableEnterpriseManagerEntityCollection": ImportableEnterpriseManagerEntityCollection,
    "IngestDatabaseConfigurationDetails": IngestDatabaseConfigurationDetails,
    "IngestDatabaseConfigurationResponseDetails": IngestDatabaseConfigurationResponseDetails,
    "IngestHostConfigurationDetails": IngestHostConfigurationDetails,
    "IngestHostConfigurationResponseDetails": IngestHostConfigurationResponseDetails,
    "IngestHostMetricsDetails": IngestHostMetricsDetails,
    "IngestHostMetricsResponseDetails": IngestHostMetricsResponseDetails,
    "IngestSqlBucketDetails": IngestSqlBucketDetails,
    "IngestSqlBucketResponseDetails": IngestSqlBucketResponseDetails,
    "IngestSqlPlanLinesDetails": IngestSqlPlanLinesDetails,
    "IngestSqlPlanLinesResponseDetails": IngestSqlPlanLinesResponseDetails,
    "IngestSqlTextDetails": IngestSqlTextDetails,
    "IngestSqlTextResponseDetails": IngestSqlTextResponseDetails,
    "MacsManagedExternalDatabaseConfigurationSummary": MacsManagedExternalDatabaseConfigurationSummary,
    "MacsManagedExternalDatabaseInsight": MacsManagedExternalDatabaseInsight,
    "MacsManagedExternalDatabaseInsightSummary": MacsManagedExternalDatabaseInsightSummary,
    "MacsManagedExternalHostInsight": MacsManagedExternalHostInsight,
    "MacsManagedExternalHostInsightSummary": MacsManagedExternalHostInsightSummary,
    "ProjectedDataItem": ProjectedDataItem,
    "ResourceCapacityTrendAggregation": ResourceCapacityTrendAggregation,
    "ResourceInsightCurrentUtilization": ResourceInsightCurrentUtilization,
    "ResourceInsightProjectedUtilization": ResourceInsightProjectedUtilization,
    "ResourceInsightProjectedUtilizationItem": ResourceInsightProjectedUtilizationItem,
    "ResourceStatistics": ResourceStatistics,
    "ResourceStatisticsAggregation": ResourceStatisticsAggregation,
    "ResourceUsageTrendAggregation": ResourceUsageTrendAggregation,
    "SqlBucket": SqlBucket,
    "SqlInsightAggregation": SqlInsightAggregation,
    "SqlInsightAggregationCollection": SqlInsightAggregationCollection,
    "SqlInsightThresholds": SqlInsightThresholds,
    "SqlInventory": SqlInventory,
    "SqlPlanCollection": SqlPlanCollection,
    "SqlPlanInsightAggregation": SqlPlanInsightAggregation,
    "SqlPlanInsightAggregationCollection": SqlPlanInsightAggregationCollection,
    "SqlPlanInsights": SqlPlanInsights,
    "SqlPlanLine": SqlPlanLine,
    "SqlPlanSummary": SqlPlanSummary,
    "SqlResponseTimeDistributionAggregation": SqlResponseTimeDistributionAggregation,
    "SqlResponseTimeDistributionAggregationCollection": SqlResponseTimeDistributionAggregationCollection,
    "SqlSearchCollection": SqlSearchCollection,
    "SqlSearchSummary": SqlSearchSummary,
    "SqlStatisticAggregation": SqlStatisticAggregation,
    "SqlStatisticAggregationCollection": SqlStatisticAggregationCollection,
    "SqlStatistics": SqlStatistics,
    "SqlStatisticsTimeSeries": SqlStatisticsTimeSeries,
    "SqlStatisticsTimeSeriesAggregation": SqlStatisticsTimeSeriesAggregation,
    "SqlStatisticsTimeSeriesAggregationCollection": SqlStatisticsTimeSeriesAggregationCollection,
    "SqlStatisticsTimeSeriesByPlanAggregation": SqlStatisticsTimeSeriesByPlanAggregation,
    "SqlStatisticsTimeSeriesByPlanAggregationCollection": SqlStatisticsTimeSeriesByPlanAggregationCollection,
    "SqlText": SqlText,
    "SqlTextCollection": SqlTextCollection,
    "SqlTextSummary": SqlTextSummary,
    "SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection": SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection,
    "SummarizeDatabaseInsightResourceForecastTrendAggregation": SummarizeDatabaseInsightResourceForecastTrendAggregation,
    "SummarizeDatabaseInsightResourceStatisticsAggregationCollection": SummarizeDatabaseInsightResourceStatisticsAggregationCollection,
    "SummarizeDatabaseInsightResourceUsageAggregation": SummarizeDatabaseInsightResourceUsageAggregation,
    "SummarizeDatabaseInsightResourceUsageTrendAggregationCollection": SummarizeDatabaseInsightResourceUsageTrendAggregationCollection,
    "SummarizeDatabaseInsightResourceUtilizationInsightAggregation": SummarizeDatabaseInsightResourceUtilizationInsightAggregation,
    "SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection": SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection,
    "SummarizeHostInsightResourceCapacityTrendAggregationCollection": SummarizeHostInsightResourceCapacityTrendAggregationCollection,
    "SummarizeHostInsightResourceForecastTrendAggregation": SummarizeHostInsightResourceForecastTrendAggregation,
    "SummarizeHostInsightResourceStatisticsAggregationCollection": SummarizeHostInsightResourceStatisticsAggregationCollection,
    "SummarizeHostInsightResourceUsageAggregation": SummarizeHostInsightResourceUsageAggregation,
    "SummarizeHostInsightResourceUsageTrendAggregationCollection": SummarizeHostInsightResourceUsageTrendAggregationCollection,
    "SummarizeHostInsightResourceUtilizationInsightAggregation": SummarizeHostInsightResourceUtilizationInsightAggregation,
    "SummaryStatistics": SummaryStatistics,
    "TablespaceUsageTrend": TablespaceUsageTrend,
    "TablespaceUsageTrendAggregation": TablespaceUsageTrendAggregation,
    "UpdateAutonomousDatabaseInsightDetails": UpdateAutonomousDatabaseInsightDetails,
    "UpdateDatabaseInsightDetails": UpdateDatabaseInsightDetails,
    "UpdateEmManagedExternalDatabaseInsightDetails": UpdateEmManagedExternalDatabaseInsightDetails,
    "UpdateEnterpriseManagerBridgeDetails": UpdateEnterpriseManagerBridgeDetails,
    "UpdateHostInsightDetails": UpdateHostInsightDetails,
    "UpdateMacsManagedExternalDatabaseInsightDetails": UpdateMacsManagedExternalDatabaseInsightDetails,
    "UpdateMacsManagedExternalHostInsightDetails": UpdateMacsManagedExternalHostInsightDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequests": WorkRequests
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UnifiedAgentLoggingSource(object):
    """
    Logging source object.
    """

    #: A constant which can be used with the source_type property of a UnifiedAgentLoggingSource.
    #: This constant has a value of "LOG_TAIL"
    SOURCE_TYPE_LOG_TAIL = "LOG_TAIL"

    #: A constant which can be used with the source_type property of a UnifiedAgentLoggingSource.
    #: This constant has a value of "WINDOWS_EVENT_LOG"
    SOURCE_TYPE_WINDOWS_EVENT_LOG = "WINDOWS_EVENT_LOG"

    def __init__(self, **kwargs):
        """
        Initializes a new UnifiedAgentLoggingSource object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.logging.models.UnifiedAgentWindowsEventSource`
        * :class:`~oci.logging.models.UnifiedAgentTailLogSource`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UnifiedAgentLoggingSource.
        :type name: str

        :param source_type:
            The value to assign to the source_type property of this UnifiedAgentLoggingSource.
            Allowed values for this property are: "LOG_TAIL", "WINDOWS_EVENT_LOG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source_type: str

        """
        self.swagger_types = {
            'name': 'str',
            'source_type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'source_type': 'sourceType'
        }

        self._name = None
        self._source_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['sourceType']

        if type == 'WINDOWS_EVENT_LOG':
            return 'UnifiedAgentWindowsEventSource'

        if type == 'LOG_TAIL':
            return 'UnifiedAgentTailLogSource'
        else:
            return 'UnifiedAgentLoggingSource'

    @property
    def name(self):
        """
        **[Required]** Gets the name of this UnifiedAgentLoggingSource.
        unique name for the source


        :return: The name of this UnifiedAgentLoggingSource.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UnifiedAgentLoggingSource.
        unique name for the source


        :param name: The name of this UnifiedAgentLoggingSource.
        :type: str
        """
        self._name = name

    @property
    def source_type(self):
        """
        **[Required]** Gets the source_type of this UnifiedAgentLoggingSource.
        Unified schema logging source type.

        Allowed values for this property are: "LOG_TAIL", "WINDOWS_EVENT_LOG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source_type of this UnifiedAgentLoggingSource.
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """
        Sets the source_type of this UnifiedAgentLoggingSource.
        Unified schema logging source type.


        :param source_type: The source_type of this UnifiedAgentLoggingSource.
        :type: str
        """
        allowed_values = ["LOG_TAIL", "WINDOWS_EVENT_LOG"]
        if not value_allowed_none_or_none_sentinel(source_type, allowed_values):
            source_type = 'UNKNOWN_ENUM_VALUE'
        self._source_type = source_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateNamespaceMetadataDetails(object):
    """
    UpdateNamespaceMetadataDetails is used to update the NamespaceMetadata. To update NamespaceMetadata, a user
    must have OBJECTSTORAGE_NAMESPACE_UPDATE permission.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateNamespaceMetadataDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param default_s3_compartment_id:
            The value to assign to the default_s3_compartment_id property of this UpdateNamespaceMetadataDetails.
        :type default_s3_compartment_id: str

        :param default_swift_compartment_id:
            The value to assign to the default_swift_compartment_id property of this UpdateNamespaceMetadataDetails.
        :type default_swift_compartment_id: str

        """
        self.swagger_types = {
            'default_s3_compartment_id': 'str',
            'default_swift_compartment_id': 'str'
        }

        self.attribute_map = {
            'default_s3_compartment_id': 'defaultS3CompartmentId',
            'default_swift_compartment_id': 'defaultSwiftCompartmentId'
        }

        self._default_s3_compartment_id = None
        self._default_swift_compartment_id = None

    @property
    def default_s3_compartment_id(self):
        """
        Gets the default_s3_compartment_id of this UpdateNamespaceMetadataDetails.
        The updated compartment id for use by an S3 client, if this field is set.


        :return: The default_s3_compartment_id of this UpdateNamespaceMetadataDetails.
        :rtype: str
        """
        return self._default_s3_compartment_id

    @default_s3_compartment_id.setter
    def default_s3_compartment_id(self, default_s3_compartment_id):
        """
        Sets the default_s3_compartment_id of this UpdateNamespaceMetadataDetails.
        The updated compartment id for use by an S3 client, if this field is set.


        :param default_s3_compartment_id: The default_s3_compartment_id of this UpdateNamespaceMetadataDetails.
        :type: str
        """
        self._default_s3_compartment_id = default_s3_compartment_id

    @property
    def default_swift_compartment_id(self):
        """
        Gets the default_swift_compartment_id of this UpdateNamespaceMetadataDetails.
        The updated compartment id for use by a Swift client, if this field is set.


        :return: The default_swift_compartment_id of this UpdateNamespaceMetadataDetails.
        :rtype: str
        """
        return self._default_swift_compartment_id

    @default_swift_compartment_id.setter
    def default_swift_compartment_id(self, default_swift_compartment_id):
        """
        Sets the default_swift_compartment_id of this UpdateNamespaceMetadataDetails.
        The updated compartment id for use by a Swift client, if this field is set.


        :param default_swift_compartment_id: The default_swift_compartment_id of this UpdateNamespaceMetadataDetails.
        :type: str
        """
        self._default_swift_compartment_id = default_swift_compartment_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttachVnicDetails(object):
    """
    AttachVnicDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AttachVnicDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param create_vnic_details:
            The value to assign to the create_vnic_details property of this AttachVnicDetails.
        :type create_vnic_details: oci.core.models.CreateVnicDetails

        :param display_name:
            The value to assign to the display_name property of this AttachVnicDetails.
        :type display_name: str

        :param instance_id:
            The value to assign to the instance_id property of this AttachVnicDetails.
        :type instance_id: str

        :param nic_index:
            The value to assign to the nic_index property of this AttachVnicDetails.
        :type nic_index: int

        """
        self.swagger_types = {
            'create_vnic_details': 'CreateVnicDetails',
            'display_name': 'str',
            'instance_id': 'str',
            'nic_index': 'int'
        }

        self.attribute_map = {
            'create_vnic_details': 'createVnicDetails',
            'display_name': 'displayName',
            'instance_id': 'instanceId',
            'nic_index': 'nicIndex'
        }

        self._create_vnic_details = None
        self._display_name = None
        self._instance_id = None
        self._nic_index = None

    @property
    def create_vnic_details(self):
        """
        **[Required]** Gets the create_vnic_details of this AttachVnicDetails.

        :return: The create_vnic_details of this AttachVnicDetails.
        :rtype: oci.core.models.CreateVnicDetails
        """
        return self._create_vnic_details

    @create_vnic_details.setter
    def create_vnic_details(self, create_vnic_details):
        """
        Sets the create_vnic_details of this AttachVnicDetails.

        :param create_vnic_details: The create_vnic_details of this AttachVnicDetails.
        :type: oci.core.models.CreateVnicDetails
        """
        self._create_vnic_details = create_vnic_details

    @property
    def display_name(self):
        """
        Gets the display_name of this AttachVnicDetails.
        A user-friendly name for the attachment. Does not have to be unique, and it cannot be changed.
        Avoid entering confidential information.


        :return: The display_name of this AttachVnicDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AttachVnicDetails.
        A user-friendly name for the attachment. Does not have to be unique, and it cannot be changed.
        Avoid entering confidential information.


        :param display_name: The display_name of this AttachVnicDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this AttachVnicDetails.
        The OCID of the instance.


        :return: The instance_id of this AttachVnicDetails.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this AttachVnicDetails.
        The OCID of the instance.


        :param instance_id: The instance_id of this AttachVnicDetails.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def nic_index(self):
        """
        Gets the nic_index of this AttachVnicDetails.
        Which physical network interface card (NIC) the VNIC will use. Defaults to 0.
        Certain bare metal instance shapes have two active physical NICs (0 and 1). If
        you add a secondary VNIC to one of these instances, you can specify which NIC
        the VNIC will use. For more information, see
        `Virtual Network Interface Cards (VNICs)`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm


        :return: The nic_index of this AttachVnicDetails.
        :rtype: int
        """
        return self._nic_index

    @nic_index.setter
    def nic_index(self, nic_index):
        """
        Sets the nic_index of this AttachVnicDetails.
        Which physical network interface card (NIC) the VNIC will use. Defaults to 0.
        Certain bare metal instance shapes have two active physical NICs (0 and 1). If
        you add a secondary VNIC to one of these instances, you can specify which NIC
        the VNIC will use. For more information, see
        `Virtual Network Interface Cards (VNICs)`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm


        :param nic_index: The nic_index of this AttachVnicDetails.
        :type: int
        """
        self._nic_index = nic_index

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .bastion import Bastion
from .bastion_summary import BastionSummary
from .change_bastion_compartment_details import ChangeBastionCompartmentDetails
from .create_bastion_details import CreateBastionDetails
from .create_managed_ssh_session_target_resource_details import CreateManagedSshSessionTargetResourceDetails
from .create_port_forwarding_session_target_resource_details import CreatePortForwardingSessionTargetResourceDetails
from .create_session_details import CreateSessionDetails
from .create_session_target_resource_details import CreateSessionTargetResourceDetails
from .managed_ssh_session_target_resource_details import ManagedSshSessionTargetResourceDetails
from .port_forwarding_session_target_resource_details import PortForwardingSessionTargetResourceDetails
from .public_key_details import PublicKeyDetails
from .session import Session
from .session_summary import SessionSummary
from .target_resource_details import TargetResourceDetails
from .update_bastion_details import UpdateBastionDetails
from .update_session_details import UpdateSessionDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for bastion services.
bastion_type_mapping = {
    "Bastion": Bastion,
    "BastionSummary": BastionSummary,
    "ChangeBastionCompartmentDetails": ChangeBastionCompartmentDetails,
    "CreateBastionDetails": CreateBastionDetails,
    "CreateManagedSshSessionTargetResourceDetails": CreateManagedSshSessionTargetResourceDetails,
    "CreatePortForwardingSessionTargetResourceDetails": CreatePortForwardingSessionTargetResourceDetails,
    "CreateSessionDetails": CreateSessionDetails,
    "CreateSessionTargetResourceDetails": CreateSessionTargetResourceDetails,
    "ManagedSshSessionTargetResourceDetails": ManagedSshSessionTargetResourceDetails,
    "PortForwardingSessionTargetResourceDetails": PortForwardingSessionTargetResourceDetails,
    "PublicKeyDetails": PublicKeyDetails,
    "Session": Session,
    "SessionSummary": SessionSummary,
    "TargetResourceDetails": TargetResourceDetails,
    "UpdateBastionDetails": UpdateBastionDetails,
    "UpdateSessionDetails": UpdateSessionDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VmClusterUpdateDetails(object):
    """
    Details specifying which maintenance update to apply to the VM Cluster and which action is to be performed by the maintenance update. Applies to Exadata Cloud@Customer instances only.
    """

    #: A constant which can be used with the update_action property of a VmClusterUpdateDetails.
    #: This constant has a value of "ROLLING_APPLY"
    UPDATE_ACTION_ROLLING_APPLY = "ROLLING_APPLY"

    #: A constant which can be used with the update_action property of a VmClusterUpdateDetails.
    #: This constant has a value of "PRECHECK"
    UPDATE_ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the update_action property of a VmClusterUpdateDetails.
    #: This constant has a value of "ROLLBACK"
    UPDATE_ACTION_ROLLBACK = "ROLLBACK"

    def __init__(self, **kwargs):
        """
        Initializes a new VmClusterUpdateDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param update_id:
            The value to assign to the update_id property of this VmClusterUpdateDetails.
        :type update_id: str

        :param update_action:
            The value to assign to the update_action property of this VmClusterUpdateDetails.
            Allowed values for this property are: "ROLLING_APPLY", "PRECHECK", "ROLLBACK"
        :type update_action: str

        """
        self.swagger_types = {
            'update_id': 'str',
            'update_action': 'str'
        }

        self.attribute_map = {
            'update_id': 'updateId',
            'update_action': 'updateAction'
        }

        self._update_id = None
        self._update_action = None

    @property
    def update_id(self):
        """
        Gets the update_id of this VmClusterUpdateDetails.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The update_id of this VmClusterUpdateDetails.
        :rtype: str
        """
        return self._update_id

    @update_id.setter
    def update_id(self, update_id):
        """
        Sets the update_id of this VmClusterUpdateDetails.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param update_id: The update_id of this VmClusterUpdateDetails.
        :type: str
        """
        self._update_id = update_id

    @property
    def update_action(self):
        """
        Gets the update_action of this VmClusterUpdateDetails.
        The update action to perform.

        Allowed values for this property are: "ROLLING_APPLY", "PRECHECK", "ROLLBACK"


        :return: The update_action of this VmClusterUpdateDetails.
        :rtype: str
        """
        return self._update_action

    @update_action.setter
    def update_action(self, update_action):
        """
        Sets the update_action of this VmClusterUpdateDetails.
        The update action to perform.


        :param update_action: The update_action of this VmClusterUpdateDetails.
        :type: str
        """
        allowed_values = ["ROLLING_APPLY", "PRECHECK", "ROLLBACK"]
        if not value_allowed_none_or_none_sentinel(update_action, allowed_values):
            raise ValueError(
                "Invalid value for `update_action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._update_action = update_action

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitorScriptParameterInfo(object):
    """
    Details of the script parameters in the monitor.
    isOverwritten specifies that the script parameters are overwritten in the monitor.
    If the user overwrites the parameter value in the monitor, then the overwritten values will be used to run the monitor.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitorScriptParameterInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param monitor_script_parameter:
            The value to assign to the monitor_script_parameter property of this MonitorScriptParameterInfo.
        :type monitor_script_parameter: oci.apm_synthetics.models.MonitorScriptParameter

        :param is_secret:
            The value to assign to the is_secret property of this MonitorScriptParameterInfo.
        :type is_secret: bool

        :param is_overwritten:
            The value to assign to the is_overwritten property of this MonitorScriptParameterInfo.
        :type is_overwritten: bool

        """
        self.swagger_types = {
            'monitor_script_parameter': 'MonitorScriptParameter',
            'is_secret': 'bool',
            'is_overwritten': 'bool'
        }

        self.attribute_map = {
            'monitor_script_parameter': 'monitorScriptParameter',
            'is_secret': 'isSecret',
            'is_overwritten': 'isOverwritten'
        }

        self._monitor_script_parameter = None
        self._is_secret = None
        self._is_overwritten = None

    @property
    def monitor_script_parameter(self):
        """
        **[Required]** Gets the monitor_script_parameter of this MonitorScriptParameterInfo.

        :return: The monitor_script_parameter of this MonitorScriptParameterInfo.
        :rtype: oci.apm_synthetics.models.MonitorScriptParameter
        """
        return self._monitor_script_parameter

    @monitor_script_parameter.setter
    def monitor_script_parameter(self, monitor_script_parameter):
        """
        Sets the monitor_script_parameter of this MonitorScriptParameterInfo.

        :param monitor_script_parameter: The monitor_script_parameter of this MonitorScriptParameterInfo.
        :type: oci.apm_synthetics.models.MonitorScriptParameter
        """
        self._monitor_script_parameter = monitor_script_parameter

    @property
    def is_secret(self):
        """
        **[Required]** Gets the is_secret of this MonitorScriptParameterInfo.
        Describes if  the parameter value is secret and should be kept confidential.
        isSecret is specified in either CreateScript or UpdateScript API.


        :return: The is_secret of this MonitorScriptParameterInfo.
        :rtype: bool
        """
        return self._is_secret

    @is_secret.setter
    def is_secret(self, is_secret):
        """
        Sets the is_secret of this MonitorScriptParameterInfo.
        Describes if  the parameter value is secret and should be kept confidential.
        isSecret is specified in either CreateScript or UpdateScript API.


        :param is_secret: The is_secret of this MonitorScriptParameterInfo.
        :type: bool
        """
        self._is_secret = is_secret

    @property
    def is_overwritten(self):
        """
        **[Required]** Gets the is_overwritten of this MonitorScriptParameterInfo.
        If parameter value is default or overwritten.


        :return: The is_overwritten of this MonitorScriptParameterInfo.
        :rtype: bool
        """
        return self._is_overwritten

    @is_overwritten.setter
    def is_overwritten(self, is_overwritten):
        """
        Sets the is_overwritten of this MonitorScriptParameterInfo.
        If parameter value is default or overwritten.


        :param is_overwritten: The is_overwritten of this MonitorScriptParameterInfo.
        :type: bool
        """
        self._is_overwritten = is_overwritten

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Suppression(object):
    """
    The full information representing an email suppression.
    """

    #: A constant which can be used with the reason property of a Suppression.
    #: This constant has a value of "UNKNOWN"
    REASON_UNKNOWN = "UNKNOWN"

    #: A constant which can be used with the reason property of a Suppression.
    #: This constant has a value of "HARDBOUNCE"
    REASON_HARDBOUNCE = "HARDBOUNCE"

    #: A constant which can be used with the reason property of a Suppression.
    #: This constant has a value of "COMPLAINT"
    REASON_COMPLAINT = "COMPLAINT"

    #: A constant which can be used with the reason property of a Suppression.
    #: This constant has a value of "MANUAL"
    REASON_MANUAL = "MANUAL"

    #: A constant which can be used with the reason property of a Suppression.
    #: This constant has a value of "SOFTBOUNCE"
    REASON_SOFTBOUNCE = "SOFTBOUNCE"

    #: A constant which can be used with the reason property of a Suppression.
    #: This constant has a value of "UNSUBSCRIBE"
    REASON_UNSUBSCRIBE = "UNSUBSCRIBE"

    def __init__(self, **kwargs):
        """
        Initializes a new Suppression object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this Suppression.
        :type compartment_id: str

        :param email_address:
            The value to assign to the email_address property of this Suppression.
        :type email_address: str

        :param id:
            The value to assign to the id property of this Suppression.
        :type id: str

        :param reason:
            The value to assign to the reason property of this Suppression.
            Allowed values for this property are: "UNKNOWN", "HARDBOUNCE", "COMPLAINT", "MANUAL", "SOFTBOUNCE", "UNSUBSCRIBE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type reason: str

        :param time_created:
            The value to assign to the time_created property of this Suppression.
        :type time_created: datetime

        :param time_last_suppressed:
            The value to assign to the time_last_suppressed property of this Suppression.
        :type time_last_suppressed: datetime

        :param message_id:
            The value to assign to the message_id property of this Suppression.
        :type message_id: str

        :param error_detail:
            The value to assign to the error_detail property of this Suppression.
        :type error_detail: str

        :param error_source:
            The value to assign to the error_source property of this Suppression.
        :type error_source: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'email_address': 'str',
            'id': 'str',
            'reason': 'str',
            'time_created': 'datetime',
            'time_last_suppressed': 'datetime',
            'message_id': 'str',
            'error_detail': 'str',
            'error_source': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'email_address': 'emailAddress',
            'id': 'id',
            'reason': 'reason',
            'time_created': 'timeCreated',
            'time_last_suppressed': 'timeLastSuppressed',
            'message_id': 'messageId',
            'error_detail': 'errorDetail',
            'error_source': 'errorSource'
        }

        self._compartment_id = None
        self._email_address = None
        self._id = None
        self._reason = None
        self._time_created = None
        self._time_last_suppressed = None
        self._message_id = None
        self._error_detail = None
        self._error_source = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Suppression.
        The OCID of the compartment to contain the suppression. Since
        suppressions are at the customer level, this must be the tenancy
        OCID.


        :return: The compartment_id of this Suppression.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Suppression.
        The OCID of the compartment to contain the suppression. Since
        suppressions are at the customer level, this must be the tenancy
        OCID.


        :param compartment_id: The compartment_id of this Suppression.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def email_address(self):
        """
        **[Required]** Gets the email_address of this Suppression.
        Email address of the suppression.


        :return: The email_address of this Suppression.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """
        Sets the email_address of this Suppression.
        Email address of the suppression.


        :param email_address: The email_address of this Suppression.
        :type: str
        """
        self._email_address = email_address

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Suppression.
        The unique ID of the suppression.


        :return: The id of this Suppression.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Suppression.
        The unique ID of the suppression.


        :param id: The id of this Suppression.
        :type: str
        """
        self._id = id

    @property
    def reason(self):
        """
        Gets the reason of this Suppression.
        The reason that the email address was suppressed. For more information on the types of bounces, see `Suppression List`__.

        __ https://docs.cloud.oracle.com/Content/Email/Concepts/overview.htm#components

        Allowed values for this property are: "UNKNOWN", "HARDBOUNCE", "COMPLAINT", "MANUAL", "SOFTBOUNCE", "UNSUBSCRIBE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The reason of this Suppression.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this Suppression.
        The reason that the email address was suppressed. For more information on the types of bounces, see `Suppression List`__.

        __ https://docs.cloud.oracle.com/Content/Email/Concepts/overview.htm#components


        :param reason: The reason of this Suppression.
        :type: str
        """
        allowed_values = ["UNKNOWN", "HARDBOUNCE", "COMPLAINT", "MANUAL", "SOFTBOUNCE", "UNSUBSCRIBE"]
        if not value_allowed_none_or_none_sentinel(reason, allowed_values):
            reason = 'UNKNOWN_ENUM_VALUE'
        self._reason = reason

    @property
    def time_created(self):
        """
        Gets the time_created of this Suppression.
        The date and time the suppression was added in \"YYYY-MM-ddThh:mmZ\"
        format with a Z offset, as defined by RFC 3339.


        :return: The time_created of this Suppression.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Suppression.
        The date and time the suppression was added in \"YYYY-MM-ddThh:mmZ\"
        format with a Z offset, as defined by RFC 3339.


        :param time_created: The time_created of this Suppression.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_suppressed(self):
        """
        Gets the time_last_suppressed of this Suppression.
        The last date and time the suppression prevented submission
        in \"YYYY-MM-ddThh:mmZ\"
        format with a Z offset, as defined by RFC 3339.


        :return: The time_last_suppressed of this Suppression.
        :rtype: datetime
        """
        return self._time_last_suppressed

    @time_last_suppressed.setter
    def time_last_suppressed(self, time_last_suppressed):
        """
        Sets the time_last_suppressed of this Suppression.
        The last date and time the suppression prevented submission
        in \"YYYY-MM-ddThh:mmZ\"
        format with a Z offset, as defined by RFC 3339.


        :param time_last_suppressed: The time_last_suppressed of this Suppression.
        :type: datetime
        """
        self._time_last_suppressed = time_last_suppressed

    @property
    def message_id(self):
        """
        Gets the message_id of this Suppression.
        The value of the Message-ID header from the email that triggered a suppression.
        This value is as defined in RFC 5322 section 3.6.4, excluding angle-brackets.
        Not provided for all types of suppressions.


        :return: The message_id of this Suppression.
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """
        Sets the message_id of this Suppression.
        The value of the Message-ID header from the email that triggered a suppression.
        This value is as defined in RFC 5322 section 3.6.4, excluding angle-brackets.
        Not provided for all types of suppressions.


        :param message_id: The message_id of this Suppression.
        :type: str
        """
        self._message_id = message_id

    @property
    def error_detail(self):
        """
        Gets the error_detail of this Suppression.
        The specific error message returned by a system that resulted in the suppression.
        This message is usually an SMTP error code with additional descriptive text.
        Not provided for all types of suppressions.


        :return: The error_detail of this Suppression.
        :rtype: str
        """
        return self._error_detail

    @error_detail.setter
    def error_detail(self, error_detail):
        """
        Sets the error_detail of this Suppression.
        The specific error message returned by a system that resulted in the suppression.
        This message is usually an SMTP error code with additional descriptive text.
        Not provided for all types of suppressions.


        :param error_detail: The error_detail of this Suppression.
        :type: str
        """
        self._error_detail = error_detail

    @property
    def error_source(self):
        """
        Gets the error_source of this Suppression.
        DNS name of the source of the error that caused the suppression.
        Will be set to either the remote-mta or reporting-mta field from a delivery status notification (RFC 3464) when available.
        Not provided for all types of suppressions, and not always known.

        Note: Most SMTP errors that cause suppressions come from software run by email receiving systems rather than from OCI email delivery itself.


        :return: The error_source of this Suppression.
        :rtype: str
        """
        return self._error_source

    @error_source.setter
    def error_source(self, error_source):
        """
        Sets the error_source of this Suppression.
        DNS name of the source of the error that caused the suppression.
        Will be set to either the remote-mta or reporting-mta field from a delivery status notification (RFC 3464) when available.
        Not provided for all types of suppressions, and not always known.

        Note: Most SMTP errors that cause suppressions come from software run by email receiving systems rather than from OCI email delivery itself.


        :param error_source: The error_source of this Suppression.
        :type: str
        """
        self._error_source = error_source

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .admin_credentials import AdminCredentials
from .agent import Agent
from .agent_collection import AgentCollection
from .agent_image_collection import AgentImageCollection
from .agent_image_summary import AgentImageSummary
from .agent_summary import AgentSummary
from .change_agent_compartment_details import ChangeAgentCompartmentDetails
from .change_connection_compartment_details import ChangeConnectionCompartmentDetails
from .change_migration_compartment_details import ChangeMigrationCompartmentDetails
from .clone_migration_details import CloneMigrationDetails
from .connect_descriptor import ConnectDescriptor
from .connection import Connection
from .connection_collection import ConnectionCollection
from .connection_summary import ConnectionSummary
from .create_admin_credentials import CreateAdminCredentials
from .create_agent_details import CreateAgentDetails
from .create_connect_descriptor import CreateConnectDescriptor
from .create_connection_details import CreateConnectionDetails
from .create_data_pump_parameters import CreateDataPumpParameters
from .create_data_pump_settings import CreateDataPumpSettings
from .create_data_transfer_medium_details import CreateDataTransferMediumDetails
from .create_database_link_details import CreateDatabaseLinkDetails
from .create_directory_object import CreateDirectoryObject
from .create_extract import CreateExtract
from .create_golden_gate_details import CreateGoldenGateDetails
from .create_golden_gate_hub import CreateGoldenGateHub
from .create_golden_gate_settings import CreateGoldenGateSettings
from .create_migration_details import CreateMigrationDetails
from .create_object_store_bucket import CreateObjectStoreBucket
from .create_private_endpoint import CreatePrivateEndpoint
from .create_replicat import CreateReplicat
from .create_ssh_details import CreateSshDetails
from .create_vault_details import CreateVaultDetails
from .data_pump_parameters import DataPumpParameters
from .data_pump_settings import DataPumpSettings
from .data_transfer_medium_details import DataTransferMediumDetails
from .database_link_details import DatabaseLinkDetails
from .database_object import DatabaseObject
from .directory_object import DirectoryObject
from .extract import Extract
from .generate_token import GenerateToken
from .golden_gate_details import GoldenGateDetails
from .golden_gate_hub import GoldenGateHub
from .golden_gate_settings import GoldenGateSettings
from .job import Job
from .job_collection import JobCollection
from .job_output_summary import JobOutputSummary
from .job_output_summary_collection import JobOutputSummaryCollection
from .job_summary import JobSummary
from .metadata_remap import MetadataRemap
from .migration import Migration
from .migration_collection import MigrationCollection
from .migration_job_progress_resource import MigrationJobProgressResource
from .migration_job_progress_summary import MigrationJobProgressSummary
from .migration_phase_collection import MigrationPhaseCollection
from .migration_phase_summary import MigrationPhaseSummary
from .migration_summary import MigrationSummary
from .object_store_bucket import ObjectStoreBucket
from .par_link import ParLink
from .phase_status import PhaseStatus
from .private_endpoint_details import PrivateEndpointDetails
from .replicat import Replicat
from .resume_job_details import ResumeJobDetails
from .ssh_details import SshDetails
from .start_migration_details import StartMigrationDetails
from .unsupported_database_object import UnsupportedDatabaseObject
from .update_admin_credentials import UpdateAdminCredentials
from .update_agent_details import UpdateAgentDetails
from .update_connect_descriptor import UpdateConnectDescriptor
from .update_connection_details import UpdateConnectionDetails
from .update_data_pump_parameters import UpdateDataPumpParameters
from .update_data_pump_settings import UpdateDataPumpSettings
from .update_data_transfer_medium_details import UpdateDataTransferMediumDetails
from .update_database_link_details import UpdateDatabaseLinkDetails
from .update_directory_object import UpdateDirectoryObject
from .update_extract import UpdateExtract
from .update_golden_gate_details import UpdateGoldenGateDetails
from .update_golden_gate_hub import UpdateGoldenGateHub
from .update_golden_gate_settings import UpdateGoldenGateSettings
from .update_job_details import UpdateJobDetails
from .update_migration_details import UpdateMigrationDetails
from .update_object_store_bucket import UpdateObjectStoreBucket
from .update_private_endpoint import UpdatePrivateEndpoint
from .update_replicat import UpdateReplicat
from .update_ssh_details import UpdateSshDetails
from .update_vault_details import UpdateVaultDetails
from .vault_details import VaultDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for database_migration services.
database_migration_type_mapping = {
    "AdminCredentials": AdminCredentials,
    "Agent": Agent,
    "AgentCollection": AgentCollection,
    "AgentImageCollection": AgentImageCollection,
    "AgentImageSummary": AgentImageSummary,
    "AgentSummary": AgentSummary,
    "ChangeAgentCompartmentDetails": ChangeAgentCompartmentDetails,
    "ChangeConnectionCompartmentDetails": ChangeConnectionCompartmentDetails,
    "ChangeMigrationCompartmentDetails": ChangeMigrationCompartmentDetails,
    "CloneMigrationDetails": CloneMigrationDetails,
    "ConnectDescriptor": ConnectDescriptor,
    "Connection": Connection,
    "ConnectionCollection": ConnectionCollection,
    "ConnectionSummary": ConnectionSummary,
    "CreateAdminCredentials": CreateAdminCredentials,
    "CreateAgentDetails": CreateAgentDetails,
    "CreateConnectDescriptor": CreateConnectDescriptor,
    "CreateConnectionDetails": CreateConnectionDetails,
    "CreateDataPumpParameters": CreateDataPumpParameters,
    "CreateDataPumpSettings": CreateDataPumpSettings,
    "CreateDataTransferMediumDetails": CreateDataTransferMediumDetails,
    "CreateDatabaseLinkDetails": CreateDatabaseLinkDetails,
    "CreateDirectoryObject": CreateDirectoryObject,
    "CreateExtract": CreateExtract,
    "CreateGoldenGateDetails": CreateGoldenGateDetails,
    "CreateGoldenGateHub": CreateGoldenGateHub,
    "CreateGoldenGateSettings": CreateGoldenGateSettings,
    "CreateMigrationDetails": CreateMigrationDetails,
    "CreateObjectStoreBucket": CreateObjectStoreBucket,
    "CreatePrivateEndpoint": CreatePrivateEndpoint,
    "CreateReplicat": CreateReplicat,
    "CreateSshDetails": CreateSshDetails,
    "CreateVaultDetails": CreateVaultDetails,
    "DataPumpParameters": DataPumpParameters,
    "DataPumpSettings": DataPumpSettings,
    "DataTransferMediumDetails": DataTransferMediumDetails,
    "DatabaseLinkDetails": DatabaseLinkDetails,
    "DatabaseObject": DatabaseObject,
    "DirectoryObject": DirectoryObject,
    "Extract": Extract,
    "GenerateToken": GenerateToken,
    "GoldenGateDetails": GoldenGateDetails,
    "GoldenGateHub": GoldenGateHub,
    "GoldenGateSettings": GoldenGateSettings,
    "Job": Job,
    "JobCollection": JobCollection,
    "JobOutputSummary": JobOutputSummary,
    "JobOutputSummaryCollection": JobOutputSummaryCollection,
    "JobSummary": JobSummary,
    "MetadataRemap": MetadataRemap,
    "Migration": Migration,
    "MigrationCollection": MigrationCollection,
    "MigrationJobProgressResource": MigrationJobProgressResource,
    "MigrationJobProgressSummary": MigrationJobProgressSummary,
    "MigrationPhaseCollection": MigrationPhaseCollection,
    "MigrationPhaseSummary": MigrationPhaseSummary,
    "MigrationSummary": MigrationSummary,
    "ObjectStoreBucket": ObjectStoreBucket,
    "ParLink": ParLink,
    "PhaseStatus": PhaseStatus,
    "PrivateEndpointDetails": PrivateEndpointDetails,
    "Replicat": Replicat,
    "ResumeJobDetails": ResumeJobDetails,
    "SshDetails": SshDetails,
    "StartMigrationDetails": StartMigrationDetails,
    "UnsupportedDatabaseObject": UnsupportedDatabaseObject,
    "UpdateAdminCredentials": UpdateAdminCredentials,
    "UpdateAgentDetails": UpdateAgentDetails,
    "UpdateConnectDescriptor": UpdateConnectDescriptor,
    "UpdateConnectionDetails": UpdateConnectionDetails,
    "UpdateDataPumpParameters": UpdateDataPumpParameters,
    "UpdateDataPumpSettings": UpdateDataPumpSettings,
    "UpdateDataTransferMediumDetails": UpdateDataTransferMediumDetails,
    "UpdateDatabaseLinkDetails": UpdateDatabaseLinkDetails,
    "UpdateDirectoryObject": UpdateDirectoryObject,
    "UpdateExtract": UpdateExtract,
    "UpdateGoldenGateDetails": UpdateGoldenGateDetails,
    "UpdateGoldenGateHub": UpdateGoldenGateHub,
    "UpdateGoldenGateSettings": UpdateGoldenGateSettings,
    "UpdateJobDetails": UpdateJobDetails,
    "UpdateMigrationDetails": UpdateMigrationDetails,
    "UpdateObjectStoreBucket": UpdateObjectStoreBucket,
    "UpdatePrivateEndpoint": UpdatePrivateEndpoint,
    "UpdateReplicat": UpdateReplicat,
    "UpdateSshDetails": UpdateSshDetails,
    "UpdateVaultDetails": UpdateVaultDetails,
    "VaultDetails": VaultDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}
